@@ -1,13 +1,13 @@
 function Foo() {
     var _newtarget = this instanceof Foo ? this.constructor : void 0;
-    const a = ()=>{
+    const a = function() {
         _newtarget;
     };
 }
 class Bar {
     constructor(){
         var _newtarget = this.constructor;
-        const a = ()=>{
+        const a = function() {
             _newtarget;
         };
     }
