@@ -1,12 +1,13 @@
+var _foo = new WeakMap(), _bar = new WeakMap();
 let Foo = function() {
     "use strict";
     function Foo() {
         _classCallCheck(this, Foo);
-        _foo.set(this, {
+        _classPrivateFieldInit(this, _foo, {
             writable: true,
             value: 1
         });
-        _bar.set(this, {
+        _classPrivateFieldInit(this, _bar, {
             writable: true,
             value: 1
         });
@@ -15,10 +16,11 @@ let Foo = function() {
         {
             key: "test",
             value: function test() {
+                var _bar1 = new WeakMap();
                 let Nested = function() {
                     function Nested() {
                         _classCallCheck(this, Nested);
-                        _bar1.set(this, {
+                        _classPrivateFieldInit(this, _bar1, {
                             writable: true,
                             value: 2
                         });
@@ -34,7 +36,6 @@ let Foo = function() {
                     ]);
                     return Nested;
                 }();
-                var _bar1 = new WeakMap();
                 _foo.has(this);
                 _bar.has(this);
             }
@@ -42,5 +43,3 @@ let Foo = function() {
     ]);
     return Foo;
 }();
-var _foo = new WeakMap();
-var _bar = new WeakMap();
